<?php

	/*
	* Plugin Name: Send UPS Access Point To Shipping Address
	* Plugin URI: https://www.pluginhive.com/product/woocommerce-ups-shipping-plugin-with-print-label/
	* Description: This plugin will replace Shipping Address Line 2 with UPS Access Point Location Address.
	* Author: PluginHive
	* Author URI: https://pluginhive.com/
	* Version: 1.0
	* Text Domain: ph_ups_access_point_to_shipping_address
	* Copyright: 2019 PluginHive.
	* WC requires at least: 3.0.0
	* WC tested up to: 3.6.2
	*/

	if ( ! defined( 'ABSPATH' ) ) {
		exit;
	}

	if ( !class_exists( 'woocommerce' ) ) {   
		add_action( 'admin_init', 'ph_ups_access_point_to_shipping_address_deactivate' );
		if ( ! function_exists( 'ph_ups_access_point_to_shipping_address_deactivate' ) ) {
			function ph_ups_access_point_to_shipping_address_deactivate() {
				if ( !class_exists( 'woocommerce' ) ){
					deactivate_plugins( plugin_basename( __FILE__ ) );
					wp_safe_redirect( admin_url('plugins.php') );
				}
			}
		}
	}

	function ph_access_point_to_shipping_address_activation_check(){

		if ( !is_plugin_active('ups-woocommerce-shipping/ups-woocommerce-shipping.php') ){
			deactivate_plugins( basename( __FILE__ ) );
			wp_die( __("Oops! You tried installing the UPS Access Point To Shipping Address without activating UPS WooCommerce Shipping Plugin. Kindly activate <b>UPS WooCommerce Shipping Plugin</b> and then try again", "ph_ups_access_point_to_shipping_address" ), "", array('back_link' => 1 ));
		}
	}

	register_activation_hook( __FILE__, 'ph_access_point_to_shipping_address_activation_check' );

	if( !class_exists('Ph_Access_Point_To_Shipping_Address') ){
		class Ph_Access_Point_To_Shipping_Address {

			public function __construct() {

				$this->id		= 'ph_ups_access_point_to_shipping_address';

				add_action('woocommerce_checkout_update_order_meta', array( $this, 'ph_add_access_point_to_shipping_address_line'), 12, 2);

			}

			function ph_add_access_point_to_shipping_address_line($order_id, $post){

				$selected_accesspoint = stripslashes( isset($_POST['shipping_accesspoint'])? $_POST['shipping_accesspoint'] : '' ) ;

				$decoded_selected_accesspoint = (isset($selected_accesspoint) && is_string($selected_accesspoint) ) ? json_decode($selected_accesspoint) : '';

				if( !empty($decoded_selected_accesspoint) )
				{

					$accesspoint_name = ( isset($decoded_selected_accesspoint->AddressKeyFormat->ConsigneeName) ) ? $decoded_selected_accesspoint->AddressKeyFormat->ConsigneeName : '';
					$accesspoint_address 	= ( isset($decoded_selected_accesspoint->AddressKeyFormat->AddressLine) )   ? $decoded_selected_accesspoint->AddressKeyFormat->AddressLine : '';
					$accesspoint_city = ( isset($decoded_selected_accesspoint->AddressKeyFormat->PoliticalDivision2) )   ? $decoded_selected_accesspoint->AddressKeyFormat->PoliticalDivision2 : '';
					$accesspoint_state = ( isset($decoded_selected_accesspoint->AddressKeyFormat->PoliticalDivision1) )   ? $decoded_selected_accesspoint->AddressKeyFormat->PoliticalDivision1 : '';
					$accesspoint_country = ( isset($decoded_selected_accesspoint->AddressKeyFormat->CountryCode) )   ? $decoded_selected_accesspoint->AddressKeyFormat->CountryCode : '';
					$accesspoint_postcode = ( isset($decoded_selected_accesspoint->AddressKeyFormat->PostcodePrimaryLow) )   ? $decoded_selected_accesspoint->AddressKeyFormat->PostcodePrimaryLow : '';

					$selected_accesspoint_locator	=	substr( $accesspoint_name .', '. $accesspoint_address .', '. $accesspoint_city .', '. $accesspoint_state .', '. $accesspoint_country .', '. $accesspoint_postcode , 0, 75 );
					
					update_post_meta( $order_id, '_shipping_address_2', $selected_accesspoint_locator );
				}

			}

		}

	}

	new Ph_Access_Point_To_Shipping_Address();